# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.team_member_amount_request import TeamMemberAmountRequest  # noqa: E501

class TestTeamMemberAmountRequest(unittest.TestCase):
    """TeamMemberAmountRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TeamMemberAmountRequest:
        """Test TeamMemberAmountRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TeamMemberAmountRequest`
        """
        model = TeamMemberAmountRequest()  # noqa: E501
        if include_optional:
            return TeamMemberAmountRequest(
                email = '',
                team_member_role_id = 56,
                portal_id = 56
            )
        else:
            return TeamMemberAmountRequest(
        )
        """

    def testTeamMemberAmountRequest(self):
        """Test TeamMemberAmountRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
